/*!\file KML_LineString.cpp
 * \brief: implementation of the kml_linestring object
 */

/*Headers:*/
/*{{{1*/
#ifdef HAVE_CONFIG_H
	#include "config.h"
#else
#error "Cannot compile with HAVE_CONFIG_H symbol! run configure first!"
#endif

#include "stdio.h"
#include <string.h>
#include "../objects.h"
#include "../../shared/shared.h"
#include "../../Container/Container.h"
#include "../../include/include.h"
/*}}}*/

/*Constructors/destructor/copy*/
/*FUNCTION KML_LineString::KML_LineString(){{{1*/
KML_LineString::KML_LineString(){

	extrude   =false;
	tessellate=false;
	strcpy(altmode   ,"clampToGround");
	ncoord    =0;
	coords    =NULL;

}
/*}}}*/
/*FUNCTION KML_LineString::~KML_LineString(){{{1*/
KML_LineString::~KML_LineString(){

	if (coords) xfree((void**)&coords);

	coords    =NULL;
	ncoord    =0;

}
/*}}}*/

/*Other*/
/*FUNCTION KML_LineString::Echo {{{1*/
void  KML_LineString::Echo(){

	bool  flag=true;

	_printf_(flag,"KML_LineString:\n");
	KML_Geometry::Echo();

	_printf_(flag,"       extrude: %s\n"          ,(extrude ? "true" : "false"));
	_printf_(flag,"    tessellate: %s\n"          ,(tessellate ? "true" : "false"));
	_printf_(flag,"       altmode: \"%s\"\n"      ,altmode);
	_printf_(flag,"        coords: (ncoord=%d)\n" ,ncoord);

	return;
}
/*}}}*/

/*FUNCTION KML_LineString::DeepEcho {{{1*/
void  KML_LineString::DeepEcho(){

	char  indent[81]="";

	KML_LineString::DeepEcho(indent);

	return;
}
/*}}}*/

/*FUNCTION KML_LineString::DeepEcho {{{1*/
void  KML_LineString::DeepEcho(char* indent){

	int   i;
	bool  flag=true;

	_printf_(flag,"%sKML_LineString:\n",indent);
	KML_Geometry::DeepEcho(indent);

	_printf_(flag,"%s       extrude: %s\n"          ,indent,(extrude ? "true" : "false"));
	_printf_(flag,"%s    tessellate: %s\n"          ,indent,(tessellate ? "true" : "false"));
	_printf_(flag,"%s       altmode: \"%s\"\n"      ,indent,altmode);
	_printf_(flag,"%s        coords: (ncoord=%d)\n" ,indent,ncoord);
	for (i=0; i<ncoord; i++)
		_printf_(flag,"%s                (%g,%g,%g)\n" ,indent,
				coords[i][0],coords[i][1],coords[i][2]);

	return;
}
/*}}}*/

/*FUNCTION KML_LineString::Write {{{1*/
void  KML_LineString::Write(FILE* filout,char* indent){

	int   i;

	if (this->id && strlen(this->id))
		fprintf(filout,"%s<LineString id=\"%s\">\n",indent,this->id);
	else
		fprintf(filout,"%s<LineString>\n",indent);

	KML_Geometry::Write(filout,indent);

	fprintf(filout,"%s  <extrude>%d</extrude>\n",indent,(extrude ? 1 : 0));
	fprintf(filout,"%s  <tessellate>%d</tessellate>\n",indent,(tessellate ? 1 : 0));
	fprintf(filout,"%s  <altitudeMode>%s</altitudeMode>\n",indent,altmode);
	fprintf(filout,"%s  <coordinates>\n",indent);

/*  loop over the coordinates for the linestring  */

	for (i=0; i<ncoord; i++)
		fprintf(filout,"%s    %0.16g,%0.16g,%0.16g\n",indent,
				coords[i][0],coords[i][1],coords[i][2]);

	fprintf(filout,"%s  </coordinates>\n",indent);
	fprintf(filout,"%s</LineString>\n",indent);

	return;
}
/*}}}*/

/*FUNCTION KML_LineString::Read {{{1*/
KML_Object*  KML_LineString::Read(FILE* filin,char* kstr){


	return(NULL);
}
/*}}}*/

/*FUNCTION KML_LineString::Id {{{1*/
int   KML_LineString::Id(){
}
/*}}}*/

/*FUNCTION KML_LineString::MyRank {{{1*/
int   KML_LineString::MyRank(){
}
/*}}}*/

/*FUNCTION KML_LineString::Marshall {{{1*/
void  KML_LineString::Marshall(char** pmarshalled_dataset){
}
/*}}}*/

/*FUNCTION KML_LineString::MarshallSize {{{1*/
int   KML_LineString::MarshallSize(){
}
/*}}}*/

/*FUNCTION KML_LineString::Demarshall {{{1*/
void  KML_LineString::Demarshall(char** pmarshalled_dataset){
}
/*}}}*/

/*FUNCTION KML_LineString::Enum {{{1*/
int   KML_LineString::Enum(){
}
/*}}}*/

/*FUNCTION KML_LineString::copy {{{1*/
Object* KML_LineString::copy(){
}
/*}}}*/

